Allows you to quickly configure your machine-learning project to use [Ray](https://github.com/ray-project/ray) for 
distributed training and tuning of your ML models on a GPU-enabled remote computer.

## Setup
1. Create a YAML configuration file named `ray_config.yaml` in the root directory of your project.
1. Ray QuickStart expects a configuration file named `ray_config.yaml` to be present in the root directory of your project.
